@@ -4,7 +4,6 @@ from datetime import datetime
 import pkg_resources
 import jsonpickle
 
-from logger.src.common.configuration.httpClientConfig import HttpClientConfig
 from logger.src.common.dto.payload import Payload
 from logger.src.common.dto.payloadDetail import PayloadDetail
 from logger.src.common.dto.payloadDetailMetadata import PayloadDetailMetadata
@@ -17,11 +16,17 @@ with requests.Session() as session:
         'Content-Type': 'application/json',
     })
 
+    host = 'http://localhost:8080'
     user_api_key = None
     user_info = None
     tags = []
 
 
+    def set_host(entered_host):
+        global host
+        host = entered_host
+
+
     def set_api_key(api_key):
         global user_api_key
         user_api_key = api_key
@@ -123,6 +128,6 @@ with requests.Session() as session:
 
 
     def create_log(payload):
-        response = session.post(f'{HttpClientConfig.alertNowURL}/integration/appinsight/v1/{user_api_key}',
+        response = session.post(f'{host}/api/integration/appinsight/v1/{user_api_key}',
                                 data=jsonpickle.encode(payload))
         return response
